@@ -41,7 +41,7 @@ from numbers import Real
 # only two required files.
 try:
     from .version import Version
-    __version__ = str(Version(fpath=__file__, archive_commit="96a53907", reponame="param"))
+    __version__ = str(Version(fpath=__file__, archive_commit="3ffe0750", reponame="param"))
 except:
     __version__ = "0.0.0+unknown"
 
@@ -1014,6 +1014,10 @@ class Tuple(Parameter):
                              (self.name,len(val),self.length))
 
 
+    @classmethod
+    def serialize(cls, value):
+        return list(value) # As JSON has no tuple representation
+
     @classmethod
     def deserialize(cls, value):
         return tuple(value) # As JSON has no tuple representation
@@ -2067,6 +2071,21 @@ class Event(Boolean):
         self._autotrigger_value = True
         self._autotrigger_reset_value = False
         self._mode = 'set-reset'
+        # Mode can be one of 'set', 'set-reset' or 'reset'
+
+        # 'set' is normal Boolean parameter behavior when set with a value.
+        # 'set-reset' temporarily sets the parameter (which triggers
+        # watching callbacks) but immediately resets the value back to
+        # False.
+        # 'reset' applies the reset from True to False without
+        # triggering watched callbacks
+
+        # This _mode attribute is one of the few places where a specific
+        # parameter has a special behavior that is relied upon by the
+        # core functionality implemented in
+        # parameterized.py. Specifically, the set_param method
+        # temporarily sets this attribute in order to disable resetting
+        # back to False while triggered callbacks are executing
         super(Event, self).__init__(default=default,**params)
 
     def _reset_event(self, obj, val):
